import 'package:flutter/material.dart';
import 'package:vegigo2_ui_common/theme/gradient_background.dart';

class ClippedGradientBanner extends StatelessWidget {
  final String title;
  final String subtitle;
  final String imgPath;

  const ClippedGradientBanner({
    Key key,
    this.title = '',
    this.subtitle = '',
    this.imgPath = ''
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GradientBackground(
      height: MediaQuery.of(context).size.height / 1.5,
      painter: ClippedBannerShadowPainter(),
      clipper: ClippedGradientBannerClipper(),
      child: Center(
        child: Column(
          children: <Widget>[
            SizedBox(height: 80),
            Text(
              title,
              style: Theme.of(context).textTheme.headline3
            ),
            SizedBox(height: 20),
            Text(
              subtitle,
              style: Theme.of(context).textTheme.subtitle1
            ),
            SizedBox(height: 40),
            Image.asset(
              imgPath,
              height: 200,
            )
          ],
        ),
      ),
    );
  }

  static Path getClippedPath(Size size) {
    final Path path = Path();
    path.lineTo(0, size.height - 100);
    path.quadraticBezierTo(size.width / 2, size.height, size.width, size.height - 100);
    path.lineTo(size.width, 0);
    path.close();
    return path;
  }
}

class ClippedGradientBannerClipper extends CustomClipper<Path> {
  @override
  Path getClip(Size size) {
    return ClippedGradientBanner.getClippedPath(size);
  }

  @override
  bool shouldReclip(covariant CustomClipper<Path> oldClipper) {
    return false;
  }
}

class ClippedBannerShadowPainter extends CustomPainter {
  @override
  void paint(Canvas canvas, Size size) {
    final Path path = ClippedGradientBanner.getClippedPath(size);

    canvas.drawShadow(path, const Color(0xff79594a), 5.0, true);
  }

  @override
  bool shouldRepaint(covariant CustomPainter oldDelegate) {
    return false;
  }
}